@@ -17,7 +17,7 @@
 
 #include <KMime/Message>
 
-#include <KIO/Global>
+#include <KFormat>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KTar>
@@ -182,12 +182,13 @@ void BackupJob::finish()
         "The archive was written to the file '%2'.",
         mRealPath.isEmpty() ? mRootFolder.name() : mRealPath,
         mMailArchivePath.path());
+    KFormat format;
     text += QLatin1Char('\n')
         + i18np("1 message of size %2 was archived.",
                 "%1 messages with the total size of %2 were archived.",
                 mArchivedMessages,
-                KIO::convertSize(mArchivedSize));
-    text += QLatin1Char('\n') + i18n("The archive file has a size of %1.", KIO::convertSize(archiveFileInfo.size()));
+                format.formatByteSize(mArchivedSize));
+    text += QLatin1Char('\n') + i18n("The archive file has a size of %1.", format.formatByteSize(archiveFileInfo.size()));
     if (mDisplayMessageBox) {
         KMessageBox::information(mParentWidget, text, i18n("Archiving finished"));
     }
@@ -234,7 +235,7 @@ void BackupJob::processMessage(const Akonadi::Item &item)
     const QByteArray messageData = message->encodedContent();
     const qint64 messageSize = messageData.size();
     const QString messageName = QString::number(item.id());
-    const QString fileName = pathForCollection(mCurrentFolder) + QLatin1String("/cur/") + messageName;
+    const QString fileName = pathForCollection(mCurrentFolder) + QLatin1StringView("/cur/") + messageName;
 
     // PORT ME: user and group!
     qCDebug(MAILCOMMON_LOG) << "AKONDI PORT: disabled code here!";
@@ -297,11 +298,11 @@ QString BackupJob::pathForCollection(const Akonadi::Collection &collection) cons
     if (collection != mRootFolder) {
         Q_ASSERT(curCol.isValid());
         while (curCol != mRootFolder) {
-            fullPath.prepend(QLatin1Char('.') + collectionName(curCol) + QLatin1String(".directory/"));
+            fullPath.prepend(QLatin1Char('.') + collectionName(curCol) + QLatin1StringView(".directory/"));
             curCol = curCol.parentCollection();
         }
         Q_ASSERT(curCol == mRootFolder);
-        fullPath.prepend(QLatin1Char('.') + collectionName(curCol) + QLatin1String(".directory/"));
+        fullPath.prepend(QLatin1Char('.') + collectionName(curCol) + QLatin1StringView(".directory/"));
     }
     return fullPath;
 }
@@ -312,7 +313,7 @@ QString BackupJob::subdirPathForCollection(const Akonadi::Collection &collection
     const int parentDirEndIndex = path.lastIndexOf(collection.name());
     Q_ASSERT(parentDirEndIndex != -1);
     path.truncate(parentDirEndIndex);
-    path.append(QLatin1Char('.') + collection.name() + QLatin1String(".directory"));
+    path.append(QLatin1Char('.') + collection.name() + QLatin1StringView(".directory"));
     return path;
 }
 
@@ -345,11 +346,11 @@ void BackupJob::archiveNextFolder()
     if (success) {
         if (!writeDirHelper(pathForCollection(mCurrentFolder))) {
             success = false;
-        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1String("/cur"))) {
+        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1StringView("/cur"))) {
             success = false;
-        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1String("/new"))) {
+        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1StringView("/new"))) {
             success = false;
-        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1String("/tmp"))) {
+        } else if (!writeDirHelper(pathForCollection(mCurrentFolder) + QLatin1StringView("/tmp"))) {
             success = false;
         }
     }
